==> modin-core-0.13.3-py38haa244fe_0.tar.bz2: Lib/site-packages/modin/core/io/__init__.py <==
# Licensed to Modin Development Team under one or more contributor license agreements.
# See the NOTICE file distributed with this work for additional information regarding
# copyright ownership.  The Modin Development Team licenses this file to you under the
# Apache License, Version 2.0 (the "License"); you may not use this file except in
# compliance with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software distributed under
# the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
# ANY KIND, either express or implied. See the License for the specific language
# governing permissions and limitations under the License.

"""IO functions implementations."""

from .io import BaseIO
from .text.csv_dispatcher import CSVDispatcher
from .text.csv_glob_dispatcher import CSVGlobDispatcher
from .text.fwf_dispatcher import FWFDispatcher
from .text.json_dispatcher import JSONDispatcher
from .text.excel_dispatcher import ExcelDispatcher
from .file_dispatcher import FileDispatcher
from .text.text_file_dispatcher import TextFileDispatcher
from .column_stores.parquet_dispatcher import ParquetDispatcher
from .column_stores.hdf_dispatcher import HDFDispatcher
from .column_stores.feather_dispatcher import FeatherDispatcher
from .sql.sql_dispatcher import SQLDispatcher
from .pickle.pickle_dispatcher import PickleExperimentalDispatcher

__all__ = [
    "BaseIO",
    "CSVDispatcher",
    "CSVGlobDispatcher",
    "FWFDispatcher",
    "JSONDispatcher",
    "FileDispatcher",
    "TextFileDispatcher",
    "ParquetDispatcher",
    "HDFDispatcher",
    "FeatherDispatcher",
    "SQLDispatcher",
    "ExcelDispatcher",
    "PickleExperimentalDispatcher",
]

==> modin-core-0.15.2-py38haa244fe_0.tar.bz2: Lib/site-packages/modin/core/io/__init__.py <==
# Licensed to Modin Development Team under one or more contributor license agreements.
# See the NOTICE file distributed with this work for additional information regarding
# copyright ownership.  The Modin Development Team licenses this file to you under the
# Apache License, Version 2.0 (the "License"); you may not use this file except in
# compliance with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software distributed under
# the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
# ANY KIND, either express or implied. See the License for the specific language
# governing permissions and limitations under the License.

"""IO functions implementations."""

from .io import BaseIO
from .text.csv_dispatcher import CSVDispatcher
from .text.csv_glob_dispatcher import CSVGlobDispatcher
from .text.fwf_dispatcher import FWFDispatcher
from .text.json_dispatcher import JSONDispatcher
from .text.custom_text_dispatcher import (
    CustomTextExperimentalDispatcher,
)
from .text.excel_dispatcher import ExcelDispatcher
from .file_dispatcher import FileDispatcher
from .text.text_file_dispatcher import TextFileDispatcher
from .column_stores.parquet_dispatcher import ParquetDispatcher
from .column_stores.hdf_dispatcher import HDFDispatcher
from .column_stores.feather_dispatcher import FeatherDispatcher
from .sql.sql_dispatcher import SQLDispatcher
from .pickle.pickle_dispatcher import PickleExperimentalDispatcher

__all__ = [
    "BaseIO",
    "CSVDispatcher",
    "CSVGlobDispatcher",
    "FWFDispatcher",
    "JSONDispatcher",
    "FileDispatcher",
    "TextFileDispatcher",
    "ParquetDispatcher",
    "HDFDispatcher",
    "FeatherDispatcher",
    "SQLDispatcher",
    "ExcelDispatcher",
    "PickleExperimentalDispatcher",
    "CustomTextExperimentalDispatcher",
]
